Documentation
¶
Overview ¶
Package terminal abstract the terminal by providing two main interfaces: Input Events and a framebuffer output
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Fder ¶
type Fder interface {
Fd() uintptr
}
Fder is the interface that wraps a Fd() filedescriptor. It is require to properly use the terminal
type Terminal ¶
type Terminal struct {
Input io.Reader
Output io.Writer
DefaultChar ansi.Char
// contains filtered or unexported fields
}
Terminal holds the state of the current terminal
Directories
¶
| Path | Synopsis |
|---|---|
|
Package ansi converts a given area into a stream of ansi sequences to be dump into a terminal
|
Package ansi converts a given area into a stream of ansi sequences to be dump into a terminal |
|
cmd
|
|
|
sequencegenerator
command
|
|
|
Package eachchange will compare two areas
|
Package eachchange will compare two areas |
|
Package events contains the basic primitives of the input and output events
|
Package events contains the basic primitives of the input and output events |
|
Package framebuffer stores the current terminal state and return the ansi sequences require to transform the current state to the new one
|
Package framebuffer stores the current terminal state and return the ansi sequences require to transform the current state to the new one |
|
Package input converts a io.Reader (normally a tty) into a sequence of events.
|
Package input converts a io.Reader (normally a tty) into a sequence of events. |
|
Package tty implements the os part of the terminal
|
Package tty implements the os part of the terminal |
Click to show internal directories.
Click to hide internal directories.